@@ -1372,11 +1372,11 @@ LIBRUBYARG_STATIC = #$LIBRUBYARG_STATIC
 
 RUBY_EXTCONF_H = #{$extconf_h}
 CFLAGS   = #{$static ? '' : CONFIG['CCDLFLAGS']} #$CFLAGS #$ARCH_FLAG
-INCFLAGS = -I. -I/usr/local/include #$INCFLAGS
+INCFLAGS = -I. #$INCFLAGS
 DEFS     = #{CONFIG['DEFS']}
 CPPFLAGS = #{extconf_h}#{$CPPFLAGS}
 CXXFLAGS = $(CFLAGS) #{CONFIG['CXXFLAGS']}
-ldflags  = -L/usr/local/lib #{$LDFLAGS}
+ldflags  = #{$LDFLAGS}
 dldflags = #{$DLDFLAGS}
 archflag = #{$ARCH_FLAG}
 DLDFLAGS = $(ldflags) $(dldflags) $(archflag)
@@ -1764,8 +1764,8 @@ def init_mkmf(config = CONFIG)
   $CFLAGS = with_config("cflags", arg_config("CFLAGS", config["CFLAGS"])).dup
   $ARCH_FLAG = with_config("arch_flag", arg_config("ARCH_FLAG", config["ARCH_FLAG"])).dup
   $CPPFLAGS = with_config("cppflags", arg_config("CPPFLAGS", config["CPPFLAGS"])).dup
-  $LDFLAGS = with_config("ldflags", arg_config("LDFLAGS", config["LDFLAGS"])).dup
-  $INCFLAGS = "-I$(topdir) -I$(hdrdir) -I$(srcdir)"
+  $LDFLAGS = with_config("ldflags", arg_config("LDFLAGS", config["LDFLAGS"])).dup + " -L/usr/local/lib"
+  $INCFLAGS = "-I$(topdir) -I$(hdrdir) -I$(srcdir) -I/usr/local/include"
   $DLDFLAGS = with_config("dldflags", arg_config("DLDFLAGS", config["DLDFLAGS"])).dup
   $LIBEXT = config['LIBEXT'].dup
   $OBJEXT = config["OBJEXT"].dup
